:py:mod:`piel.models.frequency.photonic.straight_waveguide`
===========================================================

.. py:module:: piel.models.frequency.photonic.straight_waveguide


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.straight_waveguide.waveguide



.. py:function:: waveguide(wl=1.55, wl0=1.55, neff=2.34, ng=3.4, length=10.0, loss=0.0)
